Minidjango is Django stripped down to 4 MB package size. Removed localizations
and contrib packages. Main goal is to make it less heavyweight to use ORM in the
client-side python applications.

TODO: Perhaps it can be reduced even more, contributions are welcome.
